@@ -15,9 +15,8 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * License along with this program; if not, see
+ * <http://www.gnu.org/licenses/>.
  */
 
 #ifndef __SEAHORSE_KEYSERVER_RESULTS_H__
@@ -28,7 +27,7 @@
 #include <gtk/gtk.h>
 
 #include "seahorse-common.h"
-#include "seahorse-object.h"
+#include "libseahorse/seahorse-object.h"
 
 G_BEGIN_DECLS
 
